package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IFillSymbol;
import com.esri.arcgis.display.ILineSymbol;
import com.esri.arcgis.display.LineFillSymbol;
import com.esri.arcgis.display.esriSimpleFillStyle;
import com.esri.arcgis.display.MultiLayerMarkerSymbol;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads marker line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class LineFillSymbolReader
extends AbstractSymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(LineFillSymbolReader.class);

    /**
     * Private member.
     */
    private LineFillSymbol symbol;


    public LineFillSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof LineFillSymbol) {
            this.symbol = (LineFillSymbol)symbol;
        }
        else {
            throw new Exception("Not a LineFillSymbol!");
        }
    }


    public LineFillSymbolReader(IFillSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof LineFillSymbol) {
            this.symbol = (LineFillSymbol)symbol;
        }
        else {
            throw new Exception("Not a LineFillSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");

        Element symbolElement = util.addSymbol(parent);

        symbolElement.setAttribute("name", symbol.getNameString());
        symbolElement.setAttribute("style", "fill");
        symbolElement.setAttribute(
            "offset",
            String.valueOf(symbol.getOffset()));
        symbolElement.setAttribute(
            "separation",
            String.valueOf(symbol.getSeparation()));

        if(symbol.getColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getColor();
            Color c = new Color (
                color.getRed(),
                color.getGreen(),
                color.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
            symbolElement.setAttribute("transparency",
                String.valueOf(color.getTransparency()));
        }
        else {
            RgbColor col = new RgbColor();
            col.setRGB(symbol.getColor().getRGB());
            Color c = new Color (
                col.getRed(),
                col.getGreen(),
                col.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
            symbolElement.setAttribute("transparency",
                String.valueOf(col.getTransparency()));
        }

        ILineSymbol ols = symbol.getOutline();
        LineSymbolReader olsr = new LineSymbolReader();
        if(olsr.canRead(ols)) {
            olsr.setSymbol(ols);
            olsr.setUtil(util);
            olsr.setParent(symbolElement);
            olsr.read();
        }
        else {
            logger.debug("The type of " + ols.getClass().toString() +
                         " is not implemented!");
        }
        ILineSymbol ls = symbol.getLineSymbol();
        LineSymbolReader lsr = new LineSymbolReader();
        if(lsr.canRead(ls)) {
            lsr.setSymbol(ls);
            lsr.setUtil(util);
            lsr.setParent(symbolElement);
            lsr.read();
        }
        else {
            logger.debug("The type of " + ls.getClass().toString() +
                         " is not implemented!");
        }
        return parent;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
